@@ -1,4 +1,4 @@
-# Copyright (c) 2012-2021 Trevor L. Davis <trevor.l.davis@gmail.com>
+# Copyright (c) 2012-2024 Trevor L. Davis <trevor.l.davis@gmail.com>
 #
 #  This file is free software: you may copy, redistribute and/or modify it
 #  under the terms of the GNU General Public License as published by the
@@ -40,9 +40,6 @@
 #' @references Python's \code{argparse} library, which this package is based on,
 #'  is described here: \url{https://docs.python.org/3/library/argparse.html}
 #'
-#' @import jsonlite
-#' @import R6
-#' @export
 #' @examples
 #'
 #' if (argparse:::detects_python()) {
@@ -59,6 +56,8 @@
 #'   accumulate_fn <- get(args$accumulate)
 #'   print(accumulate_fn(args$integers))
 #' }
+#' @importFrom R6 R6Class
+#' @export
 ArgumentParser <- function(..., python_cmd = NULL) { # nolint
     python_cmd <- find_python_cmd(python_cmd)
     assert_python_cmd(python_cmd)
@@ -258,7 +257,7 @@ parse_args_output <- function(output) {
 
 # @param argument argument to be converted from R to Python
 convert_argument <- function(argument, as_list = FALSE) {
-    if (is.character(argument)) argument <- paste0('"""', argument, '"""')
+    if (is.character(argument)) argument <- convert_character(argument)
     if (is.numeric(argument)) argument <- as.character(argument)
     if (is.logical(argument)) argument <- ifelse(argument, "True", "False")
     if (is.null(argument)) argument <- "None"
@@ -270,6 +269,11 @@ convert_argument <- function(argument, as_list = FALSE) {
     argument
 }
 
+convert_character <- function(s) {
+    bool <- substr(s, nchar(s), nchar(s)) == '"'
+    ifelse(bool, paste0("r'''", s, "'''"), paste0('r"""', s, '"""'))
+}
+
 get_python_type <- function(type, proposed_arguments) {
     python_type <- switch(type,
             character = "str",
@@ -364,9 +368,12 @@ assert_python_cmd <- function(python_cmd) {
     }
 }
 
-detects_python <- function() {
+required_modules <- c("argparse", "json | simplejson")
+
+detects_python <- function(...) {
     python_cmd <- try(find_python_cmd())
-    !inherits(python_cmd, "try-error")
+    !inherits(python_cmd, "try-error") &&
+        findpython::is_python_sufficient(python_cmd, ..., required_modules = required_modules)
 }
 
 # Internal function to find python cmd
@@ -376,7 +383,6 @@ find_python_cmd <- function(python_cmd = NULL) {
         python_cmd <- getOption("python_cmd")
     }
     if (is.null(python_cmd)) {
-        required_modules <- c("argparse", "json | simplejson")
         did_find_python3 <- findpython::can_find_python_cmd(minimum_version = "3.0",
                                                 required_modules = required_modules,
                                                 silent = TRUE)
